@@ -14,8 +14,8 @@ source_suffix = '.rst'
 master_doc = 'index'
 
 project = 'grpclib'
-copyright = '2019, Vladimir Magamedov'
-author = 'Vladimir Magamedov'
+copyright = '2019, Volodymyr Magamedov'
+author = 'Volodymyr Magamedov'
 
 templates_path = []
 
@@ -27,4 +27,4 @@ html_theme_options = {
 
 
 def setup(app):
-    app.add_stylesheet('style.css')
+    app.add_css_file('style.css')
