@@ -1,12 +1,15 @@
+import asyncio
+
 import pytest
+import pytest_asyncio
 
 from grpclib.config import Configuration
 
 
-@pytest.fixture(name='loop')
-def loop_fixture(event_loop):
+@pytest_asyncio.fixture(name='loop')
+async def loop_fixture():
     """ Shortcut """
-    return event_loop
+    return asyncio.get_running_loop()
 
 
 @pytest.fixture(name='config')
